@@ -3,9 +3,9 @@ Term::ReadLine::Simple::Linux;
 
 use warnings;
 use strict;
-use 5.008003;
+use 5.008000;
 
-our $VERSION = '0.208_06';
+our $VERSION = '0.011';
 
 use Term::ReadKey  qw( GetTerminalSize ReadKey ReadMode );
 
@@ -29,10 +29,10 @@ sub __reset_mode {
 }
 
 
-sub __term_buff_size {
+sub __term_buff_width {
     #my ( $self ) = @_;
-    my ( $term_width, $term_height ) = GetTerminalSize();
-    return $term_width, $term_height;
+    my ( $term_width ) = GetTerminalSize();
+    return $term_width;
 }
 
 
@@ -47,9 +47,7 @@ sub __get_key {
         }
         elsif ( $c2 eq 'O' ) {
             my $c3 = ReadKey( 0 );
-               if ( $c3 eq 'A' ) { return VK_UP; }
-            elsif ( $c3 eq 'B' ) { return VK_DOWN; }
-            elsif ( $c3 eq 'C' ) { return VK_RIGHT; }
+               if ( $c3 eq 'C' ) { return VK_RIGHT; }
             elsif ( $c3 eq 'D' ) { return VK_LEFT; }
             elsif ( $c3 eq 'F' ) { return VK_END; }
             elsif ( $c3 eq 'H' ) { return VK_HOME; }
@@ -60,9 +58,7 @@ sub __get_key {
         }
         elsif ( $c2 eq '[' ) {
             my $c3 = ReadKey( 0 );
-               if ( $c3 eq 'A' ) { return VK_UP; }
-            elsif ( $c3 eq 'B' ) { return VK_DOWN; }
-            elsif ( $c3 eq 'C' ) { return VK_RIGHT; }
+               if ( $c3 eq 'C' ) { return VK_RIGHT; }
             elsif ( $c3 eq 'D' ) { return VK_LEFT; }
             elsif ( $c3 eq 'F' ) { return VK_END; }
             elsif ( $c3 eq 'H' ) { return VK_HOME; }
@@ -70,9 +66,7 @@ sub __get_key {
             elsif ( $c3 =~ /^[0-9]$/ ) {
                 my $c4 = ReadKey( 0 );
                 if ( $c4 eq '~' ) {
-                       if ( $c3 eq '3' ) { return VK_DELETE; }
-                    elsif ( $c3 eq '5' ) { return VK_PAGE_UP; }
-                    elsif ( $c3 eq '6' ) { return VK_PAGE_DOWN; }
+                    if ( $c3 eq '3' ) { return VK_DELETE; }
                     else {
                         return NEXT_get_key;
                     }
@@ -95,40 +89,24 @@ sub __get_key {
 };
 
 
-sub __up    {
-    return if ! $_[1];
-    print "\e[${_[1]}A";
-}
+sub __up    { print "\e[${_[1]}A"; }
 
-sub __down  {
-    return if ! $_[1];
-    print "\e[${_[1]}B";
-}
 
-sub __left  {
-    return if ! $_[1];
-    print "\e[${_[1]}D"; }
+sub __left  { print "\e[${_[1]}D"; }
 
-sub __right {
-    return if ! $_[1];
-    print "\e[${_[1]}C";
-}
 
-sub __reverse { print "\e[7m"; }
+sub __right { print "\e[${_[1]}C"; }
 
-sub __reset   { print "\e[0m"; }
 
-sub __mark_current { print "\e[4m"; } # "\e[1m\e[4m";
+sub __clear_output { print "\e[0J"; }
 
-sub __clear_screen { print "\e[H\e[J"; }
 
-sub __clear_lines_to_end_of_screen { print "\r\e[0J"; }
+sub __save_cursor_position    { print "\e[s"; }
+
+
+sub __restore_cursor_position { print "\e[u"; }
 
-sub __clear_line { print "\r\e[K"; }
 
-sub __beep {
-#    print "\a";
-}
 
 1;
 
