@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 use warnings;
 use strict;
-use 5.008003;
+use 5.008000;
 
 use Term::ReadLine::Simple;
 
@@ -9,10 +9,12 @@ use FindBin qw( $RealBin );
 use lib $RealBin;
 use Data_Test_Readline;
 
-my $a_ref = Data_Test_Readline::return_test_data();
-my $args  = $a_ref->[shift]{arguments};
-
 my $tiny = Term::ReadLine::Simple->new();
-my $line = $tiny->readline( @$args );
+my $a_ref = Data_Test_Readline::return_test_data();
 
-print "<$line>\n";
+for my $ref ( @$a_ref ) {
+    my $args  = $ref->{arguments};
+
+    my $line = $tiny->readline( @$args );
+    print "<$line>\n";
+}
